@@ -15,7 +15,15 @@ public class FieldNotPresentException extends java.lang.Exception
         super();
     }
 
-    public FieldNotPresentException(String msg) {
-        super(msg);
+    public FieldNotPresentException(String mesg) {
+        super(mesg);
+    }
+
+    public FieldNotPresentException(String mesg, Throwable cause) {
+        super(mesg, cause);
+    }
+
+    public FieldNotPresentException(String mesg, Throwable cause, boolean enableSuppression, boolean writableStackTrace) {
+        super(mesg, cause, enableSuppression, writableStackTrace);
     }
 }
