@@ -12,11 +12,17 @@ public class NoSuchItemOnTokenException extends Exception {
 
     private static final long serialVersionUID = 1L;
 
-    public
-    NoSuchItemOnTokenException() {}
+    public NoSuchItemOnTokenException() {}
 
-    public
-    NoSuchItemOnTokenException( String message ) {
-        super( message );
+    public NoSuchItemOnTokenException(String mesg) {
+        super(mesg);
+    }
+
+    public NoSuchItemOnTokenException(String mesg, Throwable cause) {
+        super(mesg, cause);
+    }
+
+    public NoSuchItemOnTokenException(String mesg, Throwable cause, boolean enableSuppression, boolean writableStackTrace) {
+        super(mesg, cause, enableSuppression, writableStackTrace);
     }
 }
