@@ -33,8 +33,6 @@ import java.security.cert.CertificateException;
 import java.security.cert.X509Certificate;
 import java.util.Vector;
 
-import org.apache.commons.codec.binary.Base64;
-
 import org.mozilla.jss.netscape.security.util.Utils;
 import org.mozilla.jss.netscape.security.util.BigInt;
 import org.mozilla.jss.netscape.security.util.DerInputStream;
@@ -167,7 +165,7 @@ public class PKCS7 {
             }
         }
 
-        byte[] bytes = Base64.decodeBase64(sb.toString());
+        byte[] bytes = Utils.base64decode(sb.toString());
         parse(new DerInputStream(bytes));
     }
 
