@@ -100,15 +100,15 @@ public class DerOutputStream
      * @param tag the DER value of the context-specific tag that replaces
      *            original tag of the value in the output , such as in
      *
-     *            <pre>
-     * 	<em> <field> [N] IMPLICIT <type></em>
+       <pre>
+     *  {@literal <field>} [N] IMPLICIT {@literal <type>}
      * </pre>
      *
-     *            For example, <em>FooLength [1] IMPLICIT INTEGER</em>, with value=4;
-     *            would be encoded as "81 01 04" whereas in explicit
-     *            tagging it would be encoded as "A1 03 02 01 04".
-     *            Notice that the tag is A1 and not 81, this is because with
-     *            explicit tagging the form is always constructed.
+     * For example, <em>FooLength [1] IMPLICIT INTEGER</em>, with value=4;
+     * would be encoded as "81 01 04" whereas in explicit
+     * tagging it would be encoded as "A1 03 02 01 04".
+     * Notice that the tag is A1 and not 81, this is because with
+     * explicit tagging the form is always constructed.
      * @param value original value being implicitly tagged
      */
     public void writeImplicit(byte tag, DerOutputStream value)
@@ -312,7 +312,7 @@ public class DerOutputStream
      * Marshals a DER bit string on the output stream.
      * The bit strings need not be byte-aligned.
      *
-     * @param bits the bit string, MSB first
+     * @param ba the bit string, MSB first
      */
     public void putUnalignedBitString(BitArray ba) throws IOException {
         byte[] bits = ba.toByteArray();
@@ -328,7 +328,7 @@ public class DerOutputStream
      * All trailing 0 bits will be stripped off in accordance with DER
      * encoding.
      *
-     * @param bits the bit string, MSB first
+     * @param bitString the bit string, MSB first
      */
     public void putUnalignedBitString(byte[] bitString) throws IOException {
         putUnalignedBitString(toBitArray(bitString));
@@ -339,7 +339,7 @@ public class DerOutputStream
      * All trailing 0 bits will be stripped off in accordance with DER
      * encoding.
      *
-     * @param bits the bit string as an array of booleans.
+     * @param bitString the bit string as an array of booleans.
      */
     public void putUnalignedBitString(boolean[] bitString) throws IOException {
         putUnalignedBitString(toBitArray(bitString));
@@ -704,7 +704,7 @@ public class DerOutputStream
     /**
      * Put the tag of the attribute in the stream.
      *
-     * @param class the tag class type, one of UNIVERSAL, CONTEXT,
+     * @param tagClass the tag class type, one of UNIVERSAL, CONTEXT,
      *        APPLICATION or PRIVATE
      * @param form if true, the value is constructed, otherwise it is
      *            primitive.
