@@ -32,13 +32,17 @@ import java.io.PrintWriter;
 import java.net.InetAddress;
 import java.net.UnknownHostException;
 import java.text.SimpleDateFormat;
+import java.util.Base64;
 import java.util.Date;
 import java.util.StringTokenizer;
 import java.util.Vector;
 
-import org.apache.commons.codec.binary.Base64;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 public class Utils {
+    public static Logger logger = LoggerFactory.getLogger(Utils.class);
+
     /**
      * Checks if this is NT.
      */
@@ -374,7 +378,7 @@ public class Utils {
      * @return base-64 encoded data
      */
     public static String base64encodeMultiLine(byte[] bytes) {
-        return new Base64(64).encodeToString(bytes);
+        return Base64.getMimeEncoder().encodeToString(bytes);
     }
 
 
@@ -386,7 +390,7 @@ public class Utils {
      * @return base-64 encoded data
      */
     public static String base64encodeSingleLine(byte[] bytes) {
-        return new Base64().encodeToString(bytes);
+        return Base64.getEncoder().encodeToString(bytes);
     }
 
     /**
@@ -396,7 +400,12 @@ public class Utils {
      * @return byte array
      */
     public static byte[] base64decode(String string) {
-        return Base64.decodeBase64(string);
+        try {
+            return Base64.getMimeDecoder().decode(string);
+        } catch (IllegalArgumentException iae) {
+            logger.warn("Invalid base64: [" + string + "]: " + iae);
+            return new byte[0];
+        }
     }
 
     /**
