@@ -5,7 +5,15 @@ public class BufferProxy extends org.mozilla.jss.util.NativeProxy {
         super(pointer);
     }
 
-    protected native void releaseNativeResources();
+    /**
+     * It is usually better to call org.mozilla.jss.nss.Buffer.Free(...)
+     * instead.
+     *
+     * But this does it for you.
+     */
+    protected void releaseNativeResources() {
+        Buffer.Free(this);
+    }
 
     protected void finalize() throws Throwable {
         super.finalize();
