@@ -150,13 +150,10 @@ Java_org_mozilla_jss_pkcs11_PK11Signature_engineUpdateNative
     PR_ASSERT(ctxt != NULL);
 
     /* Get the bytes to be updated */
-    bytes = (*env)->GetByteArrayElements(env, bArray, NULL);
-    if(bytes==NULL) {
+    if (!JSS_RefByteArray(env, bArray, &bytes, &numBytes)) {
         ASSERT_OUTOFMEM(env);
         goto finish;
     }
-    numBytes = (*env)->GetArrayLength(env, bArray);
-    PR_ASSERT(numBytes > 0);
 
     if( offset < 0 || offset >= numBytes || length < 0 ||
             (offset+length) > numBytes || (offset+length) < 0 )
@@ -186,9 +183,7 @@ Java_org_mozilla_jss_pkcs11_PK11Signature_engineUpdateNative
     }
 
 finish:
-    if(bytes!=NULL) {
-        (*env)->ReleaseByteArrayElements(env, bArray, bytes, JNI_ABORT);
-    }
+    JSS_DerefByteArray(env, bArray, bytes, JNI_ABORT);
 }
 
 
@@ -205,7 +200,6 @@ Java_org_mozilla_jss_pkcs11_PK11Signature_engineSignNative
     SigContextType type;
     SECItem signature;
     jbyteArray sigArray=NULL;
-    jbyte *sigBytes=NULL;
 
     PR_ASSERT(env!=NULL && this!=NULL);
 
@@ -232,22 +226,13 @@ Java_org_mozilla_jss_pkcs11_PK11Signature_engineSignNative
     /*
      * Convert SECItem signature to Java byte array
      */
-    sigArray = (*env)->NewByteArray(env, signature.len);
-    if(sigArray == NULL) {
+    sigArray = JSS_ToByteArray(env, signature.data, signature.len);
+    if (sigArray == NULL) {
         ASSERT_OUTOFMEM(env);
         goto finish;
     }
-    sigBytes = (*env)->GetByteArrayElements(env, sigArray, NULL);
-    if(sigBytes == NULL) {
-        ASSERT_OUTOFMEM(env);
-        goto finish;
-    }
-    memcpy(sigBytes, signature.data, signature.len);
     
 finish:
-    if(sigBytes != NULL) {
-        (*env)->ReleaseByteArrayElements(env, sigArray, sigBytes, 0);
-    }
     if( signature.data != NULL ) {
         PR_Free(signature.data);
     }
@@ -284,13 +269,10 @@ Java_org_mozilla_jss_pkcs11_PK11Signature_engineVerifyNative
 	/*
 	 * Convert signature to SECItem
 	 */
-	sigItem.data = (unsigned char*)
-						(*env)->GetByteArrayElements(env, sigArray, 0);
-	if(sigItem.data == NULL) {
+	if (!JSS_RefByteArray(env, sigArray, (jbyte **) &sigItem.data, (jsize *) &sigItem.len)) {
 		ASSERT_OUTOFMEM(env);
 		goto finish;
 	}
-	sigItem.len = (*env)->GetArrayLength(env, sigArray);
 
 	/*
 	 * Finish the verification operation
@@ -305,12 +287,7 @@ Java_org_mozilla_jss_pkcs11_PK11Signature_engineVerifyNative
 	}
 
 finish:
-	if(sigItem.data!=NULL) {
-		(*env)->ReleaseByteArrayElements(	env,
-											sigArray,
-											(jbyte*)sigItem.data,
-											JNI_ABORT);
-	}
+	JSS_DerefByteArray(env, sigArray, sigItem.data, JNI_ABORT);
 	return verified;
 }
 
