@@ -99,23 +99,59 @@ class JSSKeyGeneratorSpi extends javax.crypto.KeyGeneratorSpi {
             super(KeyGenAlgorithm.RC2);
         }
     }
-
-    /**
-     * @deprecated This class name is misleading. This algorithm
-     * is used for generating Password-Based Authentication keys
-     * for use with HmacSHA1. Use PBAHmacSHA1 instead.
-     */
-    @Deprecated
     public static class HmacSHA1 extends JSSKeyGeneratorSpi {
         public HmacSHA1() {
-            super(KeyGenAlgorithm.PBA_SHA1_HMAC);
+            super(KeyGenAlgorithm.SHA1_HMAC);
         }
     }
-
     public static class PBAHmacSHA1 extends JSSKeyGeneratorSpi {
         public PBAHmacSHA1() {
             super(KeyGenAlgorithm.PBA_SHA1_HMAC);
         }
     }
-
+    public static class HmacSHA256 extends JSSKeyGeneratorSpi {
+        public HmacSHA256() {
+            super(KeyGenAlgorithm.SHA256_HMAC);
+        }
+    }
+    public static class HmacSHA384 extends JSSKeyGeneratorSpi {
+        public HmacSHA384() {
+            super(KeyGenAlgorithm.SHA384_HMAC);
+        }
+    }
+    public static class HmacSHA512 extends JSSKeyGeneratorSpi {
+        public HmacSHA512() {
+            super(KeyGenAlgorithm.SHA512_HMAC);
+        }
+    }
+    public static class KbkdfCounter extends JSSKeyGeneratorSpi {
+        public KbkdfCounter() {
+            super(KeyGenAlgorithm.SP800_108_COUNTER_KDF);
+        }
+    }
+    public static class KbkdfFeedback extends JSSKeyGeneratorSpi {
+        public KbkdfFeedback() {
+            super(KeyGenAlgorithm.SP800_108_FEEDBACK_KDF);
+        }
+    }
+    public static class KbkdfDoublePipeline extends JSSKeyGeneratorSpi {
+        public KbkdfDoublePipeline() {
+            super(KeyGenAlgorithm.SP800_108_DOUBLE_PIPELINE_KDF);
+        }
+    }
+    public static class KbkdfCounterData extends JSSKeyGeneratorSpi {
+        public KbkdfCounterData() {
+            super(KeyGenAlgorithm.NSS_SP800_108_COUNTER_KDF_DERIVE_DATA);
+        }
+    }
+    public static class KbkdfFeedbackData extends JSSKeyGeneratorSpi {
+        public KbkdfFeedbackData() {
+            super(KeyGenAlgorithm.NSS_SP800_108_FEEDBACK_KDF_DERIVE_DATA);
+        }
+    }
+    public static class KbkdfDoublePipelineData extends JSSKeyGeneratorSpi {
+        public KbkdfDoublePipelineData() {
+            super(KeyGenAlgorithm.NSS_SP800_108_DOUBLE_PIPELINE_KDF_DERIVE_DATA);
+        }
+    }
 }
