@@ -25,6 +25,8 @@
 #define AF_INET6 23
 #endif
 
+#include "SSLVersionRange.h"
+
 
 /*
  * support TLS v1.1, v1.2, and v1.3
@@ -39,8 +41,6 @@ Java_org_mozilla_jss_ssl_SSLSocket_boundSSLVersionRange(JNIEnv *env,
     SSLVersionRange vrange;
     SSLVersionRange supported_range;
     jobject versionRange = NULL;
-    jclass versionRangeClass;
-    jmethodID versionRangeCons;
 
     if (ssl_variant <0 || ssl_variant >= JSSL_enums_size||
             min <0 || min >= JSSL_enums_size ||
@@ -68,40 +68,9 @@ Java_org_mozilla_jss_ssl_SSLSocket_boundSSLVersionRange(JNIEnv *env,
     supported_range.min = MAX(supported_range.min, vrange.min);
     supported_range.max = MIN(supported_range.max, vrange.max);
 
-    /* convert new min/max values back to the JSSL_enums indexes */
-    for (int i = 0; i < JSSL_enums_size; i++) {
-        if (JSSL_enums[i] == supported_range.min) {
-            supported_range.min = i;
-            break;
-        }
-    }
-    for (int i = 0; i < JSSL_enums_size; i++) {
-        if (JSSL_enums[i] == supported_range.max) {
-            supported_range.max = i;
-            break;
-        }
-    }
+    /* wrap NSS's SSLVersionRange into a org.mozilla.jss.ssl.SSLVersionRange */
+    versionRange = JSS_SSL_wrapVersionRange(env, supported_range);
 
-    /*
-     * package the status into a new SSLVersionRange object
-     */
-    versionRangeClass = (*env)->FindClass(env, SSL_VERSION_RANGE_CLASS_NAME);
-    PR_ASSERT(versionRangeClass != NULL);
-    if( versionRangeClass == NULL ) {
-        /* exception was thrown */
-        goto finish;
-    }
-
-    versionRangeCons = (*env)->GetMethodID(env, versionRangeClass,
-                            SSL_VERSION_RANGE_CONSTRUCTOR_NAME,
-                            SSL_VERSION_RANGE_CONSTRUCTOR_SIG);
-    PR_ASSERT(versionRangeCons != NULL);
-    if(versionRangeCons == NULL ) {
-        /* exception was thrown */
-        goto finish;
-    }
-    versionRange = (*env)->NewObject(env, versionRangeClass, versionRangeCons,
-            supported_range.min, supported_range.max);
 finish:
     return versionRange;
 }
@@ -644,12 +613,7 @@ Java_org_mozilla_jss_ssl_SSLSocket_socketConnect
     supportsIPV6 = (*env)->CallStaticBooleanMethod(env, socketBaseClass,
          supportsIPV6ID);
 
-    addrBAelems = (*env)->GetByteArrayElements(env, addrBA, NULL);
-    addrBALen = (*env)->GetArrayLength(env, addrBA);
-
-    PR_ASSERT(addrBALen != 0);
-
-    if( addrBAelems == NULL ) {
+    if (!JSS_RefByteArray(env, addrBA, &addrBAelems, &addrBALen)) {
         ASSERT_OUTOFMEM(env);
         goto finish;
     }
@@ -658,7 +622,7 @@ Java_org_mozilla_jss_ssl_SSLSocket_socketConnect
      * Tell SSL the URL we think we want to connect to.
      * This prevents man-in-the-middle attacks.
      */
-    hostnameStr = (*env)->GetStringUTFChars(env, hostname, NULL);
+    hostnameStr = JSS_RefJString(env, hostname);
     if( hostnameStr == NULL ) goto finish;
     stat = SSL_SetURL(sock->fd, (char*)hostnameStr);
     if( stat != 0 ) {
@@ -706,12 +670,8 @@ finish:
     /* This method should never be called on a Java socket wrapper. */
     PR_ASSERT( sock==NULL || sock->jsockPriv==NULL);
 
-    if( hostnameStr != NULL ) {
-        (*env)->ReleaseStringUTFChars(env, hostname, hostnameStr);
-    }
-    if( addrBAelems != NULL ) {
-        (*env)->ReleaseByteArrayElements(env, addrBA, addrBAelems, JNI_ABORT);
-    }
+    JSS_DerefJString(env, hostname, hostnameStr);
+    JSS_DerefByteArray(env, addrBA, addrBAelems, JNI_ABORT);
 }
 
 JNIEXPORT jobject JNICALL
@@ -938,15 +898,13 @@ Java_org_mozilla_jss_ssl_SSLSocket_socketRead(JNIEnv *env, jobject self,
     PRIntervalTime ivtimeout;
     PRThread *me;
     jint nread = -1;
-    
-    size = (*env)->GetArrayLength(env, bufBA);
-    if( off < 0 || len < 0 || (off+len) > size) {
-        JSS_throw(env, INDEX_OUT_OF_BOUNDS_EXCEPTION);
+
+    if (!JSS_RefByteArray(env, bufBA, &buf, &size)) {
         goto finish;
     }
 
-    buf = (*env)->GetByteArrayElements(env, bufBA, NULL);
-    if( buf == NULL ) {
+    if (off < 0 || len < 0 || (off+len) > size) {
+        JSS_throw(env, INDEX_OUT_OF_BOUNDS_EXCEPTION);
         goto finish;
     }
 
@@ -1010,7 +968,7 @@ Java_org_mozilla_jss_ssl_SSLSocket_socketRead(JNIEnv *env, jobject self,
 
 finish:
     EXCEPTION_CHECK(env, sock)
-    (*env)->ReleaseByteArrayElements(env, bufBA, buf,
+    JSS_DerefByteArray(env, bufBA, buf,
         (nread>0) ? 0 /*copy and free*/ : JNI_ABORT /*free, no copy*/);
     return nread;
 }
@@ -1045,22 +1003,15 @@ Java_org_mozilla_jss_ssl_SSLSocket_socketWrite(JNIEnv *env, jobject self,
     PRThread *me;
     PRInt32 numwrit;
 
-    if( bufBA == NULL ) {
-        JSS_throw(env, NULL_POINTER_EXCEPTION);
+    if (!JSS_RefByteArray(env, bufBA, &buf, &size)) {
         goto finish;
     }
 
-    size = (*env)->GetArrayLength(env, bufBA);
-    if( off < 0 || len < 0 || (off+len) > size ) {
+    if (off < 0 || len < 0 || (off+len) > size) {
         JSS_throw(env, INDEX_OUT_OF_BOUNDS_EXCEPTION);
         goto finish;
     }
 
-    buf = (*env)->GetByteArrayElements(env, bufBA, NULL);
-    if( buf == NULL ) {
-        goto finish;
-    }
-
     ivtimeout = (timeout > 0) ? PR_MillisecondsToInterval(timeout)
                               : PR_INTERVAL_NO_TIMEOUT;
 
@@ -1115,9 +1066,7 @@ Java_org_mozilla_jss_ssl_SSLSocket_socketWrite(JNIEnv *env, jobject self,
     PR_ASSERT(numwrit == len);
 
 finish:
-    if( buf != NULL ) {
-        (*env)->ReleaseByteArrayElements(env, bufBA, buf, JNI_ABORT);
-    }
+    JSS_DerefByteArray(env, bufBA, buf, JNI_ABORT);
     EXCEPTION_CHECK(env, sock)
 }
 
