@@ -9,6 +9,7 @@ import java.io.UnsupportedEncodingException;
 import org.mozilla.jss.crypto.SecretKeyFacade;
 import org.mozilla.jss.crypto.AlreadyInitializedException;
 import org.mozilla.jss.crypto.CryptoToken;
+import org.mozilla.jss.crypto.Policy;
 import org.mozilla.jss.crypto.TokenException;
 import javax.crypto.SecretKey;
 import javax.crypto.BadPaddingException;
@@ -86,11 +87,11 @@ public class JCAKeyWrap {
             // Generate an RSA keypair
             KeyPairGenerator kpgen;
             kpgen = KeyPairGenerator.getInstance("RSA", MOZ_PROVIDER_NAME);
-            kpgen.initialize(1024);
+            kpgen.initialize(Policy.RSA_MINIMUM_KEY_SIZE);
             KeyPair rsaKeyPairNSS = kpgen.generateKeyPair();
 
             kpgen = KeyPairGenerator.getInstance("RSA", otherRSAProvider);
-            kpgen.initialize(1024);
+            kpgen.initialize(Policy.RSA_MINIMUM_KEY_SIZE);
             KeyPair rsaKeyPairOtherProvider = kpgen.generateKeyPair();
 
             javax.crypto.SecretKey tripleDESKey;
