@@ -8,4 +8,9 @@ public class IncorrectPasswordException extends Exception {
     private static final long serialVersionUID = 1L;
     public IncorrectPasswordException() { super(); }
     public IncorrectPasswordException(String mesg) { super(mesg); }
+    public IncorrectPasswordException(String mesg, Throwable cause) { super(mesg, cause); }
+
+    public IncorrectPasswordException(String mesg, Throwable cause, boolean enableSuppression, boolean writableStackTrace) {
+        super(mesg, cause, enableSuppression, writableStackTrace);
+    }
 }
