@@ -31,7 +31,7 @@ public abstract class NativeProxy implements AutoCloseable
 
     /**
      * Create a NativeProxy from a byte array representing a C pointer.
-     * This is the only way to create a NativeProxy, it should be called
+     * This is the primary way of creating a NativeProxy; it should be called
      * from the constructor of your subclass.
      *
      * @param pointer A byte array, created with JSS_ptrToByteArray, that
@@ -39,12 +39,27 @@ public abstract class NativeProxy implements AutoCloseable
      * NativeProxy instance acts as a proxy for that native data structure.
      */
     public NativeProxy(byte[] pointer) {
-		assert(pointer!=null);
-        registry.add(this);
+        this(pointer, true);
+    }
+
+    /**
+     * Create a NativeProxy from a byte array representing a C pointer.
+     * This allows for creating an untracked NativeProxy instance (when
+     * track=false), which allows for creating NativeProxy instances out
+     * of stack-allocated variables and/or creating NativeProxies which
+     * aren't freed.
+     */
+    protected NativeProxy(byte[] pointer, boolean track) {
         mPointer = pointer;
 
-        if (saveStacktraces) {
-            mTrace = Arrays.toString(Thread.currentThread().getStackTrace());
+        if (track) {
+            assert(pointer != null);
+
+            registry.add(this);
+
+            if (saveStacktraces) {
+                mTrace = Arrays.toString(Thread.currentThread().getStackTrace());
+            }
         }
     }
 
@@ -61,15 +76,12 @@ public abstract class NativeProxy implements AutoCloseable
         if( ! (obj instanceof NativeProxy) ) {
             return false;
         }
-        if( ((NativeProxy)obj).mPointer.length != mPointer.length) {
+        if (((NativeProxy)obj).mPointer == null) {
+            /* If mPointer is null, we have no way to compare the values
+             * of the pointers, so assume they're unequal. */
             return false;
         }
-        for(int i=0; i < mPointer.length; i++) {
-            if(mPointer[i] != ((NativeProxy)obj).mPointer[i]) {
-                return false;
-            }
-        }
-        return true;
+        return Arrays.equals(((NativeProxy)obj).mPointer, mPointer);
     }
 
     /**
